@@ -6,8 +6,8 @@ http://sima-pc.com/nif.php
 http://en.wikipedia.org/wiki/Vat_number
 '''
 
-__version__ = '0.7'
-VIES_URL='http://ec.europa.eu/taxation_customs/vies/services/checkVatService.wsdl'
+__version__ = '0.9'
+VIES_URL='http://ec.europa.eu/taxation_customs/vies/checkVatService.wsdl'
 
 def countries():
     '''
@@ -598,8 +598,12 @@ def check_vat_gb(vat):
         check_sum = 8 * int(vat[0]) + 7 * int(vat[1]) + 6 * int(vat[2]) + \
                 5 * int(vat[3]) + 4 * int(vat[4]) + 3 * int(vat[5]) + \
                 2 * int(vat[6]) + 10 * int(vat[7]) + int(vat[8])
-        if check_sum % 97 != 0:
-            return False
+        if int(vat[0:3]) > 100:
+            if check_sum % 97 not in (0, 55, 42):
+                return False
+        else:
+            if check_sum % 97 != 0:
+                return False
         return True
     return False
 
@@ -1165,7 +1169,11 @@ def check_vat(vat):
     '''
     code = vat[:2].lower()
     number = vat[2:]
-    return globals()['check_vat_%s' % code](number)
+    try:
+        checker = globals()['check_vat_%s' % code]
+    except KeyError:
+        return False
+    return checker(number)
 
 def check_vies(vat):
     '''
